# WorkItemChangeModel


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**work_item_id** | **str** |  | [optional] 
**old_version_id** | **str** |  | [optional] 
**new_version_id** | **str** |  | [optional] 
**work_item_changed_fields** | [**WorkItemChangedFieldsViewModel**](WorkItemChangedFieldsViewModel.md) |  | [optional] 
**created_by_id** | **str** |  | [optional] 
**created_date** | **datetime, none_type** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


